@@ -29,14 +29,17 @@
 )]
 
 mod app;
+mod cfg;
 mod gen;
 mod output;
 mod syntax;
 
+use crate::cfg::{CfgValue, FlagsCfgEvaluator};
 use crate::gen::error::{report, Result};
 use crate::gen::fs;
 use crate::gen::include::{self, Include};
 use crate::output::Output;
+use std::collections::{BTreeMap as Map, BTreeSet as Set};
 use std::io::{self, Write};
 use std::path::PathBuf;
 use std::process;
@@ -48,6 +51,7 @@ struct Opt {
     cxx_impl_annotations: Option<String>,
     include: Vec<Include>,
     outputs: Vec<Output>,
+    cfg: Map<String, Set<CfgValue>>,
 }
 
 fn main() {
@@ -91,6 +95,7 @@ fn try_main() -> Result<()> {
         cxx_impl_annotations: opt.cxx_impl_annotations,
         gen_header,
         gen_implementation,
+        cfg_evaluator: Box::new(FlagsCfgEvaluator::new(opt.cfg)),
         ..Default::default()
     };
 
